:mod:`art.metrics`
==================
.. automodule:: art.metrics

Clique Method Robustness Verification
-------------------------------------
.. autoclass:: RobustnessVerificationTreeModelsCliqueMethod
   :members:
   :special-members:

Loss Sensitivity
----------------
.. autofunction:: loss_sensitivity

Empirical Robustness
--------------------
.. autofunction:: empirical_robustness

CLEVER
------
.. autofunction:: clever_u
.. autofunction:: clever_t

Wasserstein Distance
--------------------
.. autofunction:: wasserstein_distance
